# Generate initial conditions for simulations of fishery in Tun Mustapha Park, Malaysia
# CJ Brown 10 Jan 2014
#
#Supplementary file for:
# Christopher J. Brown, Crow White, Maria Beger, Hedley S. Grantham, Benjamin S. Halpern, Carissa J. Klein, Peter J. Mumby, Vivitskaia J.D. Tulloch, Mary Ruckelshaus and Hugh P. Possingham. Fisheries and biodiversity benefits of using static versus dynamic models for designing marine reserve networks. Ecosphere
#
# Generates stable age distribution, equilibrium abundance file and also dispersal matrix.
# Run fishery model, after initialisation, to generate stable age distribution
#
# You need to have function and type declarations .jl files in your current directory.
# Also the parameter specification file.
#For Julia version 0.3.2

using Gaston
set_terminal("aqua")

# Load functions and type declarations
require("FishMod_types.jl")
reload("Fishmod_Functions.jl")
#NB later versions of Julia don't support using 'require()' to read type declarations.

##########
# SET PARAMETERS
##########

reload("FishParams_TMP.jl")

# Initial recruitment and age-strucuture
reczero = min(sp_params.repro.alphar./sp_params.repro.betaer)
reczeromat = sp_params.repro.alphar./sp_params.repro.betaer
reczeromat= repmat(reczeromat,1, initparams.nages)
ages = [0:sp_params.growth.maxage]
agesmat = transpose(repmat(ages, 1,run_params.ncells))
abundzero =reczero .* (exp(-sp_params.popn.mnat .*ages))
ninit = reczeromat .* (exp(-sp_params.popn.mnat .*agesmat))

##########
# RUN MODEL
##########
tic()
modres = fishmod(run_params, fishery_params, sp_params,initparams, ninit)
toc()
####

##########
# SAVE EQUILIBRIUM CONDITIONS AND DISPERSAL MATRIX
##########
####
filenm = string("InitCond_",runname,"_",fishery_params.btot,".csv")
# Save equilbrium condition
writecsv(filenm, modres.nvals)

writecsv("DispersalMatrix.csv", initparams.pmatrix)


##########
# PLOTS FOR CHECKING
##########

figure(1)
plot(ages, modres.nvals[2,:], "xlabel","Age", "ylabel", "Abundance",
ages, abundzero, "color","blue")


figure(2)
plot([1:run_params.nyears], sum(modres.maturebio,1), "xlabel","Years", "ylabel", "Mature biomass")

figure(8)
plot([1:run_params.nyears], modres.maturebio[12,:]./initparams.lzero,
 "xlabel","Years", "ylabel", "Mature biomass over max biomass in one cell",
[1:run_params.nyears], modres.maturebio[1,:]./initparams.lzero)

figure(3)
valmat = matrix_values_map(grefsallF, grefs, modres.maturebio[:,run_params.nyears], -1.)
imagesc(valmat,"title","Mature biomass")

figure(10)
valmat = matrix_values_map(grefsallF, grefs, modres.pvals[:,run_params.nyears], -1.)
imagesc(valmat,"title","Profits over space")

figure(4)
plot([1:run_params.nyears], sum(modres.hvals,1), "xlabel","Years", "ylabel", "Harvest")

figure(5)
plot([1:run_params.nyears], sum(modres.pvals,1), "xlabel","Years", "ylabel", "Profits")


figure(6)
plot(hab_map_params.habdist_qual, modres.maturebio[:,run_params.nyears], "plotstyle","points",
 "pointsize",3, "xlabel","Hab quality", "ylabel","Biomass")


figure(8)
plot(modres.hvals[:,99],modres.hvals[:,100], "xlabel","year 99 harvest","ylabel","year 100 harvest","plotstyle","points")

figure(9)
plot(modres.pvals[:,99],modres.pvals[:,100], "xlabel","year 99 abundance","ylabel","year 100 abundance","plotstyle","points")

### Plot SR curve
stock = linspace(0.,initparams.lzero,20) #need to edit these numbers
recruits1 = (sp_params.repro.alphar[1].*stock) ./ (1 + (min(sp_params.repro.betaer).*stock))
recruits2 = (sp_params.repro.alphar[1].*stock) ./ (1 + (max(sp_params.repro.betaer).*stock))
figure(7)
plot(stock, recruits1, stock, recruits2)

println("Range of recruitment values")
println(min(modres.nvals[:,1]))
print(max(modres.nvals[:,1]))

#### Age stucture
#for i = 1:5
#figure(i+4)
#histogram(modres[4][:,i+19])
#end

